@@ -4,28 +4,29 @@ Contains writer base class.
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
 
-from traitlets import List
+from traitlets import List, Unicode
 
-from ..utils.base import NbConvertBase
+from nbconvert.utils.base import NbConvertBase
 
 
 class WriterBase(NbConvertBase):
     """Consumes output from nbconvert export...() methods and writes to a
-    useful location. """
-
-
-    files = List([], help="""
-        List of the files that the notebook references.  Files will be 
-        included with written output.""").tag(config=True)
+    useful location."""
 
+    files = List(
+        Unicode(),
+        help="""
+        List of the files that the notebook references.  Files will be
+        included with written output.""",
+    ).tag(config=True)
 
     def __init__(self, config=None, **kw):
         """
         Constructor
         """
-        super(WriterBase, self).__init__(config=config, **kw)
-
+        super().__init__(config=config, **kw)
 
     def write(self, output, resources, **kw):
         """
